/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: editaccount.h 277 2005-08-24 16:52:02Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQBANKING_KDE_EDITACCOUNT_H
#define AQBANKING_KDE_EDITACCOUNT_H

class KBanking;
class Account;

#include "editaccount.ui.h"
#include "refpointer.h"



class EditAccount: public EditAccountUi {
  Q_OBJECT
public:
  EditAccount(KBanking *app,
              Account *a,
              bool isCreate=false,
              QWidget* parent=0,
              const char* name=0,
              bool modal=false,
              WFlags fl=0);
  ~EditAccount();

public slots:
  void accept();
  void reject();
  void slotBankCode();

private:
  KBanking *_app;
  Account *_account;
  bool _isCreate;

  static QString _tr(const char * sourceText);

};







#endif // AQBANKING_KDE_EDITACCOUNT_H


